from Products.CMFCore.utils import getToolByName

def install(self, product=None, reinstall=None):
    """ Custom install tasks
    """
    catalogTool = getToolByName(self, 'portal_catalog')
    
    # Add indexes if they don't exist:
    def addCatalogIndex(indexName, indexType):   
        try:
            catalogTool.delIndex(indexName)
        except:
            pass
        catalogTool.addIndex(indexName, indexType)
        catalogTool.reindexIndex(indexName, None)
        
    addCatalogIndex('getSortableName', 'FieldIndex')
    addCatalogIndex('getRawClassifications', 'KeywordIndex')
    addCatalogIndex('getRawSpecialties', 'KeywordIndex')
    
    # Add metadata fields if they don't exist:
    fieldName = "UID"
    if fieldName not in catalogTool.schema():
        catalogTool.addColumn(fieldName)
        catalogTool.refreshCatalog()

    #Set up nav tree
    mtntl = list(self.portal_properties.navtree_properties.metaTypesNotToList)
    metaTypes = ['Course', 'Person']
    for mType in metaTypes: 
        if not mType in mtntl:
            mtntl.append(mType)
    self.portal_properties.navtree_properties._p_changed=1
    self.portal_properties.navtree_properties.metaTypesNotToList=tuple(mtntl)
        
    #Add action icon for vCards        
    ai=getToolByName(self, 'portal_actionicons')
    try:
        ai.getActionInfo('plone','vcard')
    except KeyError:
        # Action icon doesn't exist. Add it.
        ai.addActionIcon('plone', 'vcard', 'vcard.png', 'vCard export')
    
    #Set up Kupu
    def addKupuResource(resourceType, portalType):
        kupu = getToolByName(self, 'kupu_library_tool')
        resourceList = list(kupu.getPortalTypesForResourceType(resourceType))
        if portalType not in resourceList:
            resourceList.append(portalType)
            kupu.addResourceType(resourceType,tuple(resourceList))
            kupu.updateResourceTypes(resourceType)
    
    addKupuResource('linkable','Person')
    addKupuResource('mediaobject','Person')
    addKupuResource('collection','FacultyStaffDirectory')
    
    
    #Set up SmartFolder/Topic/Collection fields
    
    def addSmartFolderIndex(indexName, friendlyName, description, criteria):
        smart_folder_tool = getToolByName(self, 'portal_atct')           
        # Remove existing indexes if there are some
        try:
            smart_folder_tool.removeIndex(indexName)
        except:
            pass
        smart_folder_tool.addIndex(indexName, friendlyName, description, enabled=True, criteria=criteria)
    
    addSmartFolderIndex("getRawClassifications", "Classification", "The classification assigned to a person", criteria=['ATReferenceCriterion'])
    addSmartFolderIndex("getRawSpecialties", "Specialty", "A person's listed specialty areas", criteria=['ATReferenceCriterion'])
    

def uninstall(self, product=None, reinstall=None):
    """ Custom uninstall tasks
    """
    
    #Remove classes from NavTree_properties
    mtntl = list(self.portal_properties.navtree_properties.metaTypesNotToList)
    metaTypes = ['Course', 'Person']
    for mType in metaTypes: 
        if mType in self.portal_properties.navtree_properties.metaTypesNotToList:
            mtntl.remove(mType)
    self.portal_properties.navtree_properties._p_changed=1
    self.portal_properties.navtree_properties.metaTypesNotToList = tuple(mtntl)
        
    #Remove action icon for vCards        
    ai=getToolByName(self, 'portal_actionicons')
    try:
        ai.removeActionIcon('plone', 'vcard')
    except KeyError:
        #Icon doesn't exist, problem solved.
        pass
        
  
    #Remove added indexes
    def removeCatalogIndex(indexName):
        catalogTool = getToolByName(self, 'portal_catalog')
        if indexName in catalogTool.indexes():
            catalogTool.delIndex(indexName)
            
    removeCatalogIndex('getSortableName')
    removeCatalogIndex('getRawClassifications')        
    
    #Remove Kupu customizations
    def removeKupuResource(resourceType, portalType):
        kupu = getToolByName(self, 'kupu_library_tool')
        resourceList = list(kupu.getPortalTypesForResourceType(resourceType))
        if portalType in resourceList:
            resourceList.remove(portalType)
            kupu.addResourceType(resourceType,tuple(resourceList))
            kupu.updateResourceTypes(resourceType)        

    removeKupuResource('linkable','Person')
    removeKupuResource('mediaobject','Person')
    removeKupuResource('collection','FacultyStaffDirectory')
    
    
    

      
